package com.kym.huapiaoer.model.request;

import lombok.Data;
import lombok.experimental.Accessors;

import java.util.List;

@Data
@Accessors(chain = true)
public class OpenBlueInvoiceRequest {
    private String issuerid;

    private TradeInfo tradeinfo;

    private HeadInfo head;

    private List<DetailInfo> details;

    @Data
    @Accessors(chain = true)
    public static class TradeInfo {
        private String payType;
        private String outTradeNo;
    }

    @Data
    @Accessors(chain = true)
    public static class HeadInfo {
        private String companyid;
        private String kpje;
        private String orderId;
        private String b2cshopid;
        private String invoicetitle;
        private String registrationnumber;
        private String companyaddress;
        private String mobilenumber;
        private String openaccountbank;
        private String bankaccount;
        private String remark;
        private String recmail;
        private String invoiceTypeCode;
    }

    @Data
    @Accessors(chain = true)
    public static class DetailInfo {
        private String goodscategory;
        private String taxcode;
        private String tax;
        private String goodsname;
        private Double price;
        private Double sl;
        private String attributes;
        private String unitname;
        private Double discount;
    }
}
